% Script 3: CGCI in greek stocks and networks
alpha = 0.05; % significance level
K = 5; % Number of variables (time series) to use from the set of variables read in.
M = 100; % The number of time-shifted surrogates for the nonparametric 
         % (randomization) test
P = 2; % The order of the VAR model used for the computation of the 
        % conditional Granger causality index (CGCI) 
offsetfrac = 0.1; % For time-shifted surrogates, to shift long enough

yM = load('d:\MyFiles\Teach\TimeSeriesVolos\lab\stocks2003.dat');
[n,m]=size(yM);
% rand('state',0)
% Read the names of the stocks
nameM = textread('d:\MyFiles\Teach\TimeSeriesVolos\lab\stock_names.dat','%s');
nameM = nameM(iV(1:K),:);

iV = randperm(m);
% iV = [1:m];
yM = yM(:,iV(1:K));

% Read the names of the stocks
nameM = textread('d:\MyFiles\Teach\TimeSeriesVolos\lab\stock_names.dat','%s');
nameM = nameM(iV(1:K),:);

% If NaN replace them with interpolated values for each time series
for i=1:K
    i1V = find(isnan(yM(:,i)));
    if ~isempty(i1V)
        iokV = setdiff([1:n]',i1V);
        yM(i1V,i) = interp1(iokV,yM(iokV,i),i1V,'spline');
    end
end

% Use log returns
xM = log(yM(2:n,:))-log(yM(1:n-1,:));
[n,m]=size(xM);

% Granger causality index, GCI
gciM = NaN(K,K);
pgciM = NaN(K,K);
for ik=1:K-1
    for jk=ik+1:K
        [gciM(ik,jk),gciM(jk,ik),pgciM(ik,jk),pgciM(jk,ik)] = GCin(xM(:,ik),xM(:,jk),P,1);                       
    end
end
% Conditional Granger causality index, CGCI
[cgciM,pcgciM] = CGCinall(xM,P,1);

% Networks for GCI
tit1txt = sprintf('GCI_{X->Y}(%d)',P);
h1 = plotnetworktitle(gciM,[],nameM,tit1txt,1);

tit2txt = sprintf('Adjacency for GCI_{X->Y}(%d) for alpha=%1.3f',P,alpha);
adjgciM = pgciM < alpha;
h2 = plotnetworktitle(adjgciM,[],nameM,tit2txt,2);

fdrgciM = adjFDRmatrix(pgciM,alpha,2);
tit3txt = sprintf('FDR (a=%1.3f), parametric p-value, GCI_{X->Y}(%d)',alpha,P);
h3 = plotnetworktitle(fdrgciM,[],nameM,tit3txt,3);

% Networks for CGCI
tit4txt = sprintf('CGCI_{X->Y}(%d)',P);
h1 = plotnetworktitle(cgciM,[],nameM,tit4txt,4);

tit5txt = sprintf('Adjacency for CGCI_{X->Y}(%d) for alpha=%1.3f',P,alpha);
adjcgciM = pcgciM < alpha;
h5 = plotnetworktitle(adjcgciM,[],nameM,tit5txt,5);

fdrcgciM = adjFDRmatrix(pcgciM,alpha,2);
tit6txt = sprintf('FDR (a=%1.3f), parametric p-value, CGCI_{X->Y}(%d)',alpha,P);
h6 = plotnetworktitle(fdrcgciM,[],nameM,tit6txt,6);

